<?php
/**
 * Starter Gazette functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package starter_gazette
 */

if (!function_exists('starter_gazette_setup')):
    /**
     * Sets up theme defaults and registers support for various WordPress features.
     *
     * Note that this function is hooked into the after_setup_theme hook, which
     * runs before the init hook. The init hook is too late for some features, such
     * as indicating support for post thumbnails.
     */
    function starter_gazette_setup()
    {
        /*
         * Make theme available for translation.
         * Translations can be filed in the /languages/ directory.
         * If you're building a theme based on Starter Gazette, use a find and replace
         * to change 'starter-gazette' to the name of your theme in all the template files.
         */
        load_theme_textdomain('starter-gazette');

        // Add default posts and comments RSS feed links to head.
        add_theme_support('automatic-feed-links');

        /*
         * Let WordPress manage the document title.
         * By adding theme support, we declare that this theme does not use a
         * hard-coded <title> tag in the document head, and expect WordPress to
         * provide it for us.
         */
        add_theme_support('title-tag');

        /*
         * Enable support for Post Thumbnails on posts and pages.
         *
         * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
         */
        add_theme_support('post-thumbnails');
        add_image_size('starter-gazette-720-480', 720, 720, true);
        add_image_size('starter-gazette-full-1200-900', 1200, 900, true);
        add_image_size('starter-gazette-full-800-600', 800, 600, true);

        // This theme uses wp_nav_menu() in one location.
        register_nav_menus(array(
            'mainnav' => esc_html__('Primary Menu', 'starter-gazette'),
            'topnav' => esc_html__('Top Menu', 'starter-gazette'),
            'social' => __('Social Menu', 'starter-gazette'),
        ));

        /*
         * Switch default core markup for search form, comment form, and comments
         * to output valid HTML5.
         */
        add_theme_support('html5', array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
        ));

        // Set up the WordPress core custom background feature.
        add_theme_support('custom-background', apply_filters('starter_gazette_custom_background_args', array(
            'default-color' => 'ffffff',
            'default-image' => '',
        )));

        // Add theme support for selective refresh for widgets.
        add_theme_support('customize-selective-refresh-widgets');

        /**
         * Add support for core custom logo.
         *
         * @link https://codex.wordpress.org/Theme_Logo
         */
        add_theme_support('custom-logo', array(
            'flex-width' => true,
            'flex-height' => true,
        ));

        // Set up the WordPress core custom header feature.
        add_theme_support('custom-header', apply_filters('starter_gazette_custom_header_args', array(
            'width' => 1920,
            'height' => 1080,
            'flex-height' => true,
            'header-text' => false,
        )));

    }
endif;
add_action('after_setup_theme', 'starter_gazette_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function starter_gazette_content_width()
{
    $GLOBALS['content_width'] = apply_filters('starter_gazette_content_width', 640);
}

add_action('after_setup_theme', 'starter_gazette_content_width', 0);

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function starter_gazette_widgets_init()
{
    register_sidebar(array(
        'name' => esc_html__('Sidebar', 'starter-gazette'),
        'id' => 'sidebar-1',
        'description' => esc_html__('Add widgets here.', 'starter-gazette'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h2 class="widget-title">',
        'after_title' => '</h2>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer Column 1', 'starter-gazette'),
        'id' => 'footer-col-1',
        'description' => esc_html__('Displays items on footer section.', 'starter-gazette'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title">',
        'after_title' => '</h5>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer Column 2', 'starter-gazette'),
        'id' => 'footer-col-2',
        'description' => esc_html__('Displays items on footer section.', 'starter-gazette'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title">',
        'after_title' => '</h5>',
    ));
    register_sidebar(array(
        'name' => esc_html__('Footer Column 3', 'starter-gazette'),
        'id' => 'footer-col-3',
        'description' => esc_html__('Displays items on footer section.', 'starter-gazette'),
        'before_widget' => '<div id="%1$s" class="widget %2$s">',
        'after_widget' => '</div>',
        'before_title' => '<h5 class="widget-title">',
        'after_title' => '</h5>',
    ));
}

add_action('widgets_init', 'starter_gazette_widgets_init');

/**
 * Add Google Font
 */
if (!function_exists('starter_gazette_fonts_url')):

    /**
     * Return fonts URL.
     *
     * @since 1.0.0
     * @return string Fonts URL.
     */
    function starter_gazette_fonts_url()
    {

        $fonts_url = '';
        $fonts = array();

        $starter_gazette_primary_font = starter_gazette_get_option('primary_font');
        $starter_gazette_site_title_font = starter_gazette_get_option('site_title_font');
        $starter_gazette_secondary_font = starter_gazette_get_option('secondary_font');

        $starter_gazette_fonts = array();
        $starter_gazette_fonts[] = $starter_gazette_primary_font;
        $starter_gazette_fonts[] = $starter_gazette_site_title_font;
        $starter_gazette_fonts[] = $starter_gazette_secondary_font;

        $starter_gazette_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

        $i = 0;
        for ($i = 0; $i < count($starter_gazette_fonts); $i++) {

            if ('off' !== sprintf(_x('on', '%s font: on or off', 'starter-gazette'), $starter_gazette_fonts[$i])) {
                $fonts[] = $starter_gazette_fonts[$i];
            }

        }

        if ($fonts) {
            $fonts_url = add_query_arg(array(
                'family' => urldecode(implode('|', $fonts)),
            ), 'https://fonts.googleapis.com/css');
        }
        return $fonts_url;
    }
endif;

/**
 * Enqueue scripts and styles.
 */
function starter_gazette_scripts()
{
    $min = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '' : '.min';

    $fonts_url = starter_gazette_fonts_url();
    if (!empty($fonts_url)) {
        wp_enqueue_style('starter-gazette-google-fonts', $fonts_url, array(), null);
    }

    wp_enqueue_style('jquery-slick', get_template_directory_uri() . '/assets/src/slick/css/slick' . $min . '.css');
    wp_enqueue_style('elegant-icon', get_template_directory_uri() . '/assets/src/elegant-icon/style.css');
    wp_enqueue_style('magnific-popup', get_template_directory_uri() . '/assets/src/magnific-popup/magnific-popup.css');
    wp_enqueue_style('ticker', get_template_directory_uri() . '/assets/src/jquery-ticker/ticker.css');
    wp_enqueue_style('sidr-nav', get_template_directory_uri() . '/assets/src/sidr/css/jquery.sidr.dark.css');

    wp_enqueue_style('starter-gazette-style', get_stylesheet_uri());

    wp_enqueue_script('starter-gazette-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true);

    wp_enqueue_script('starter-gazette-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true);

    wp_enqueue_script('jquery-slick', get_template_directory_uri() . '/assets/src/slick/js/slick' . $min . '.js', array('jquery'), '', true);
    wp_enqueue_script('jquery-magnific-popup', get_template_directory_uri() . '/assets/src/magnific-popup/jquery.magnific-popup' . $min . '.js', array('jquery'), '', true);
    wp_enqueue_script('theiaStickySidebar', get_template_directory_uri() . '/assets/src/theiaStickySidebar/theia-sticky-sidebar' . $min . '.js', array('jquery'), '', true);
    wp_enqueue_script('jquery-ticker', get_template_directory_uri() . '/assets/src/jquery-ticker/jquery.ticker' . $min . '.js', array('jquery'), '', true);
    wp_enqueue_script('jquery-sidr', get_template_directory_uri() . '/assets/src/sidr/js/jquery.sidr' . $min . '.js', array('jquery'), '', true);
    wp_enqueue_script('starter-gazette-script', get_template_directory_uri() . '/js/script.js', array('jquery'), '', 1);

    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
    wp_add_inline_style('starter-gazette-style', starter_gazette_custom_css());

}

add_action('wp_enqueue_scripts', 'starter_gazette_scripts');

/**
 * Enqueue admin scripts and styles.
 */
function starter_gazette_admin_scripts()
{
    wp_enqueue_style('admin-style', get_template_directory_uri() . '/assets/css/admin-style.css');
}

add_action('admin_enqueue_scripts', 'starter_gazette_admin_scripts');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions for this theme.
 */
require get_template_directory() . '/inc/custom-functions.php';

/**
 * Custom hooks for this theme.
 */
require get_template_directory() . '/inc/custom-hooks.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * SVG icons functions and filters.
 */
require get_parent_theme_file_path('/inc/icon-functions.php');

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
    require get_template_directory() . '/inc/jetpack.php';
}


//* Add description to menu items
add_filter('walker_nav_menu_start_el', 'starter_gazette_add_description', 10, 2);
function starter_gazette_add_description($item_output, $item)
{
    $description = $item->post_content;
    if (('' !== $description) && (' ' !== $description)) {
        return preg_replace('/(<a.*)</', '$1' . '<span class="menu-description">' . $description . '</span><', $item_output);
    } else {
        return $item_output;
    };
}

/**
 * CSS related hooks.
 */

if (!function_exists('starter_gazette_custom_css')) :

    /**
     * Do action theme custom CSS.
     *
     * @since 1.0.0
     */
    function starter_gazette_custom_css()
    {
        global $starter_gazette_google_fonts;

        $starter_gazette_banner_overlay = starter_gazette_get_option('enable_overlay_option');

        $starter_gazette_primary_color = starter_gazette_get_option('primary_color');
        $starter_gazette_secondary_color = starter_gazette_get_option('secondary_color');
        $starter_gazette_tertiary_color = starter_gazette_get_option('tertiary_color');
        $starter_gazette_primary_font = $starter_gazette_google_fonts[starter_gazette_get_option('primary_font')];
        $starter_gazette_secondary_font = $starter_gazette_google_fonts[starter_gazette_get_option('secondary_font')];

        $starter_gazette_site_title_font = $starter_gazette_google_fonts[starter_gazette_get_option('site_title_font')];


        $starter_gazette_featured_background_color = starter_gazette_get_option('featured_background_color');
        $starter_gazette_featured_text_color = starter_gazette_get_option('featured_text_color');
        $starter_gazette_featured_border_color = starter_gazette_get_option('featured_border_color');

        ?>
        <style type="text/css">
            <?php
            /* Banner Image */
            if ( $starter_gazette_banner_overlay == 1 ){ ?>
            .overlay.overlay-enable:before {
                content: "";
            }
            <?php } ?>

            <?php if (!empty ($starter_gazette_primary_color)) { ?>
            body .site .wp-block-quote,
            body .site .social-navigation a,
            body .site button,
            body .site input[type="button"],
            body .site input[type="reset"],
            body .site input[type="submit"],
            body .site .navigation.pagination .page-numbers.current,
            body .site .tagcloud > a:hover,
            body .site .tagcloud > a:focus,
            body .site .social-navigation a:hover,
            body .site .social-navigation a:focus,
            body .site button:hover,
            body .site button:active,
            body .site button:focus,
            body .site input[type="button"]:hover,
            body .site input[type="button"]:focus,
            body .site input[type="button"]:active,
            body .site input[type="reset"]:hover,
            body .site input[type="reset"]:active,
            body .site input[type="reset"]:focus,
            body .site input[type="submit"]:hover,
            body .site input[type="submit"]:active,
            body .site input[type="submit"]:focus {
                background: <?php echo esc_html($starter_gazette_primary_color); ?>;
            }

            body .site .btn-link:link:hover,
            body .site .btn-link:visited:hover {
                color: <?php echo esc_html($starter_gazette_primary_color); ?>;
            }

            body .site .btn-link {
                border-color: <?php echo esc_html($starter_gazette_primary_color); ?>;
            }

            @media only screen and (min-width: 992px) {
                body .site .main-navigation ul ul li a:hover,
                body .site .main-navigation ul ul li a:focus {
                    background: <?php echo esc_html($starter_gazette_primary_color); ?>;
                }
            }

            <?php } ?>

            <?php if (!empty ($starter_gazette_secondary_color)) { ?>
            body .site .comment-form .submit:hover,
            body .site .comment-form .submit:active,
            body .site .comment-form .submit:focus,
            body .site .mc4wp-form-fields input[type="submit"],
            body .site .main-navigation .menu ul > li.current_page_item > a,
            body .site .main-navigation .menu ul > li:focus > a,
            body .site .main-navigation .menu ul > li:hover > a,
            body .site .main-navigation .menu ul > li.current_page_item > a:before,
            body .site .main-navigation .menu ul > li:focus > a:before,
            body .site .main-navigation .menu ul > li:hover > a:before,
            body .site .menu-description,
            body .site .footer-social-menu,
            body .site #scroll-up{
                background: <?php echo esc_html($starter_gazette_secondary_color);?>;
            }

            body .site .site-title,
            body .site .site-title a,
            body .site .entry-meta a,
            body .site .entry-footer a,
            body .site a:hover,
            body .site a:focus,
            body .site a:active {
                color: <?php echo esc_html($starter_gazette_secondary_color); ?>;
            }

            <?php } ?>

            <?php if(!empty($starter_gazette_tertiary_color)){ ?>
            .site .breaking-news-title,
            .site .exclusive-news-box .ticker-controls li:hover,
            body .entry-meta-bullets > span a {
                background: <?php echo esc_html($starter_gazette_tertiary_color); ?>;
            }

            .site .banner-tiles .entry-meta-bullets > span a:after{
                border-top-color: <?php echo esc_html($starter_gazette_tertiary_color); ?>;
            }

            <?php } ?>

            <?php if(!empty($starter_gazette_primary_font)){ ?>
            body,
            body button,
            body input,
            body select,
            body optgroup,
            body textarea {
                font-family: <?php echo esc_html($starter_gazette_primary_font); ?> !important;
            }

            body .site h1,
            body .site h2,
            body .site h3,
            body .site h4,
            body .site h5,
            body .site h6 {

            }

            <?php } ?>

            <?php if(!empty($starter_gazette_site_title_font)){ ?>
            body .site .site-title {
                font-family: <?php echo esc_html($starter_gazette_site_title_font); ?> !important;
            }

            <?php } ?>

            <?php if(!empty($starter_gazette_featured_background_color)){ ?>
            body .site .united-block.featured-carousel {
                background: <?php echo esc_html($starter_gazette_featured_background_color); ?>;
            }

            <?php } ?>

            <?php if(!empty($starter_gazette_featured_text_color)){ ?>
            body .site .united-block.featured-carousel,
            body .site .united-block.featured-carousel .title-header,
            body .site .featured-carousel .hentry .photo-grid .entry-header .entry-title a {
                color: <?php echo esc_html($starter_gazette_featured_text_color); ?>;
            }

            <?php } ?>

            <?php if(!empty($starter_gazette_featured_border_color)){ ?>
            body .site .united-block.featured-carousel .carousel-slider .item {
                border-color: <?php echo esc_html($starter_gazette_featured_border_color); ?>;
            }

            <?php } ?>

        </style>

    <?php }

endif;